@@ -4,9 +4,7 @@ use warnings;
 
 package Log::Any::Manager;
 
-our $VERSION = '1.03';
-
-use Carp qw(croak);
+our $VERSION = '1.032';
 
 sub new {
     my $class = shift;
@@ -79,8 +77,10 @@ sub set {
     }
     my ( $adapter_name, @adapter_params ) = @_;
 
-    croak "expected adapter name"
-      unless defined($adapter_name) && $adapter_name =~ /\S/;
+    unless ( defined($adapter_name) && $adapter_name =~ /\S/ ) {
+        require Carp;
+        Carp::croak("expected adapter name");
+    }
 
     my $pattern = $options->{category};
     if ( !defined($pattern) ) {
