@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.03';
+our $VERSION = '1.032';
 
 use Log::Any::Adapter::Util ();
 
@@ -27,10 +27,14 @@ sub _dump_one_line {
 sub new {
     my $class = shift;
     my $self = { formatter => \&_default_formatter, @_ };
-    Carp::croak("$class requires an 'adapter' parameter")
-      unless $self->{adapter};
-    Carp::croak("$class requires an 'category' parameter")
-      unless $self->{category};
+    unless ( $self->{adapter} ) {
+        require Carp;
+        Carp::croak("$class requires an 'adapter' parameter");
+    }
+    unless ( $self->{category} ) {
+        require Carp;
+        Carp::croak("$class requires an 'category' parameter")
+    }
     bless $self, $class;
     $self->init(@_);
     return $self;
@@ -96,7 +100,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.03
+version 1.032
 
 =head1 SYNOPSIS
 
